@@ -79,18 +79,6 @@ class LarkUtilTestCase(TestCase):
         self.assertTrue(response)
         self.assertTrue(response["folderToken"] == config.TEMPLATE_FOLDER_TOKEN)
 
-    def test_copy_docs_to_public_folder(self):
-        copy_data = {
-            "type": "sheet",
-            "dstFolderToken": 'fldcnGILr9HSkUZ2sBJRuyYqhEg',
-            "dstName": random_string(),
-            "permissionNeeded": False,
-            "CommentNeeded": False,
-        }
-        response = self.lark_docs.copy_docs(config.SHEET_TOKEN, copy_data)
-        self.assertTrue(response)
-        self.assertTrue(response["folderToken"] == config.TEMPLATE_FOLDER_TOKEN)
-
     def test_create_permissions(self):
         member = [
             {"member_type": "email", "member_id": config.OTHER_EMAIL, "perm": "view"}
@@ -119,6 +107,10 @@ class LarkUtilTestCase(TestCase):
         response = self.lark_docs.unlock_sheet(config.SHEET_TOKEN, config.SHEET_ID)
         self.assertTrue(response)
 
+    def test_get_root_folder_metadata(self):
+        response = self.lark_docs.get_root_folder_metadata()
+        self.assertTrue(response)
+
 
 if __name__ == "__main__":
     # 生成登录回调链接
